@@ -146,7 +146,7 @@ EwsSyncFolderItemsRequest::Response::Response(QXmlStreamReader &reader)
         return;
     }
 
-    static const QVector<EwsXml<SyncFolderItemsResponseElementType>::Item> items = {
+    static const QList<EwsXml<SyncFolderItemsResponseElementType>::Item> items = {
         {SyncState, QStringLiteral("SyncState"), &ewsXmlTextReader},
         {IncludesLastItemInRange, QStringLiteral("IncludesLastItemInRange"), &ewsXmlBoolReader},
         {Changes, QStringLiteral("Changes"), &EwsSyncFolderItemsRequest::Response::changeReader},
@@ -193,7 +193,7 @@ bool EwsSyncFolderItemsRequest::Response::changeReader(QXmlStreamReader &reader,
 
 EwsSyncFolderItemsRequest::Change::Change(QXmlStreamReader &reader)
 {
-    static const QVector<EwsXml<SyncFolderItemsChangeElementType>::Item> items = {
+    static const QList<EwsXml<SyncFolderItemsChangeElementType>::Item> items = {
         {Item, QStringLiteral("Item"), &ewsXmlItemReader},
         {Item, QStringLiteral("Message"), &ewsXmlItemReader},
         {Item, QStringLiteral("CalendarItem"), &ewsXmlItemReader},
@@ -235,7 +235,7 @@ EwsSyncFolderItemsRequest::Change::Change(QXmlStreamReader &reader)
     case ReadFlagChange:
         mIsRead = values[IsRead].toBool();
         /* fall through */
-        Q_FALLTHROUGH();
+        [[fallthrough]];
     case Delete:
         mId = values[ItemId].value<EwsId>();
         break;
@@ -243,3 +243,5 @@ EwsSyncFolderItemsRequest::Change::Change(QXmlStreamReader &reader)
         break;
     }
 }
+
+#include "moc_ewssyncfolderitemsrequest.cpp"
