@@ -7,7 +7,7 @@
 
 #include "resourcetask.h"
 
-#include <Akonadi/KMime/MessageFlags>
+#include <Akonadi/MessageFlags>
 
 #include "imapresource_debug.h"
 #include "imapresource_trace.h"
@@ -298,7 +298,7 @@ void ResourceTask::changesCommitted(const Akonadi::Item::List &items)
     deleteLater();
 }
 
-void ResourceTask::searchFinished(const QVector<qint64> &result, bool isRid)
+void ResourceTask::searchFinished(const QList<qint64> &result, bool isRid)
 {
     if (!mCancelled) {
         m_resource->searchFinished(result, isRid);
@@ -546,3 +546,5 @@ void ResourceTask::setItemMergingMode(Akonadi::ItemSync::MergeMode mode)
 {
     m_resource->setItemMergingMode(mode);
 }
+
+#include "moc_resourcetask.cpp"
